export interface Config {
    [index: string]: object | string | number | boolean;
    ARCHIVER_IP: string;
    ARCHIVER_PORT: number;
    ARCHIVER_HASH_KEY: string;
    ARCHIVER_PUBLIC_KEY: string;
    ARCHIVER_SECRET_KEY: string;
    ARCHIVER_DB: string;
    ARCHIVER_DATA: {
        cycleDB: string;
        accountDB: string;
        transactionDB: string;
        receiptDB: string;
        originalTxDataDB: string;
        processedTxDB: string;
        txDigestDB: string;
        checkpointStatusDB: string;
    };
    DATASENDER_TIMEOUT: number;
    RATE_LIMIT: number;
    N_NODE_REJECT_PERCENT: number;
    N_NODELIST: number;
    N_RANDOM_NODELIST_BUCKETS: number;
    RECEIPT_CONFIRMATIONS: number;
    STATISTICS: {
        save: boolean;
        interval: number;
    };
    ARCHIVER_MODE: string;
    DevPublicKey: string;
    checkpoint: {
        bucketConfig: {
            BucketMatureAge: number;
            cycleAge: number;
            GiveUpAge: number;
            lastFailedBucketDuration: number;
            RadixDepth: number;
            allowCheckpointUpdates: boolean;
            allowCheckpointStorage: boolean;
        };
        batchSize: number;
        updateInterval: number;
        syncInterval: number;
        maxCyclesToSync: number;
        syncOnStartup: boolean;
    };
    dataLogWrite: boolean;
    dataLogWriter: {
        dirName: string;
        maxLogFiles: number;
        maxReceiptEntries: number;
        maxCycleEntries: number;
        maxOriginalTxEntries: number;
    };
    experimentalSnapshot: boolean;
    failedBucketsDir: string;
    VERBOSE: boolean;
    useSerialization: boolean;
    useSyncV2: boolean;
    sendActiveMessage: boolean;
    globalNetworkAccount: string;
    maxValidatorsToServe: number;
    limitToArchiversOnly: boolean;
    verifyReceiptData: boolean;
    verifyReceiptSignaturesSeparately: boolean;
    verifyAppReceiptData: boolean;
    verifyAccountData: boolean;
    REQUEST_LIMIT: {
        MAX_ACCOUNTS_PER_REQUEST: number;
        MAX_RECEIPTS_PER_REQUEST: number;
        MAX_ORIGINAL_TXS_PER_REQUEST: number;
        MAX_CYCLES_PER_REQUEST: number;
        MAX_BETWEEN_CYCLES_PER_REQUEST: number;
    };
    cycleRecordsCache: {
        enabled: boolean;
    };
    newPOQReceipt: boolean;
    storeReceiptBeforeStates: boolean;
    waitingTimeForMissingTxData: number;
    gossipToMoreArchivers: true;
    randomGossipArchiversCount: 2;
    subscribeToMoreConsensors: boolean;
    extraConsensorsToSubscribe: 1;
    saveOnlyGossipData: boolean;
    stopGossipTxData: boolean;
    usePOQo: boolean;
    requiredVotesPercentage: number;
    requiredMajorityVotesPercentage: number;
    maxCyclesShardDataToKeep: number;
    configChangeMaxCyclesToKeep: number;
    configChangeMaxChangesToKeep: number;
    receiptLoadTrakerInterval: number;
    receiptLoadTrakerLimit: number;
    lastActivityCheckInterval: number;
    lastActivityCheckTimeout: number;
    txDigest: {
        cycleDiff: number;
        syncDelay: number;
        apiServerPort: number;
        txCronSchedule: string;
    };
    workerProcessesDebugLog: boolean;
    restrictFirstNodeSelectionByPublicKey: boolean;
    firstNodePublicKey: string;
    disableOffloadReceipt: boolean;
    disableOffloadReceiptForGlobalModification: boolean;
    restoreNGTsFromSnapshot: boolean;
    tickets: {
        allowedTicketSigners: {
            [pubkey: string]: number;
        };
        minSigRequired: number;
        requiredSecurityLevel: number;
    };
    maxRecordsPerRequest: number;
    multisigKeysSyncFromNetworkInternal: number;
    minCycleConfirmationsToSave: number;
    nerfNonFoundationCertScores: boolean;
    formingNetworkCycleThreshold: number;
    maxResponseSize: number;
}
declare let config: Config;
export declare function overrideDefaultConfig(file: string): Promise<void>;
export declare function updateConfig(newConfig: Partial<Config>): Config;
export { config };
