"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.core = exports.authenticate = exports.tag = exports.getOrCreateSharedKey = exports.getOrCreateCurvePk = exports.verify = exports.sign = exports.hashObj = exports.hash = exports.setCryptoHashKey = void 0;
const core = require("@shardeum-foundation/lib-crypto-utils");
exports.core = core;
const lib_types_1 = require("@shardeum-foundation/lib-types");
const State = require("./State");
// Crypto initialization fns
function setCryptoHashKey(hashkey) {
    core.init(hashkey);
    core.setCustomStringifier(lib_types_1.Utils.safeStringify, 'shardus_safeStringify');
}
exports.setCryptoHashKey = setCryptoHashKey;
exports.hash = core.hash;
exports.hashObj = core.hashObj;
function sign(obj) {
    const objCopy = lib_types_1.Utils.safeJsonParse(core.stringify(obj));
    core.signObj(objCopy, State.getSecretKey(), State.getNodeInfo().publicKey);
    return objCopy;
}
exports.sign = sign;
function verify(obj) {
    return core.verifyObj(obj);
}
exports.verify = verify;
const curvePublicKeys = new Map();
const sharedKeys = new Map();
function getOrCreateCurvePk(pk) {
    let curvePk = curvePublicKeys.get(pk);
    if (!curvePk) {
        curvePk = core.convertPkToCurve(pk);
        curvePublicKeys.set(pk, curvePk);
    }
    return curvePk;
}
exports.getOrCreateCurvePk = getOrCreateCurvePk;
function getOrCreateSharedKey(pk) {
    let sharedK = sharedKeys.get(pk);
    if (!sharedK) {
        const ourCurveSk = State.getCurveSk();
        const theirCurvePk = getOrCreateCurvePk(pk);
        sharedK = core.generateSharedKey(ourCurveSk, theirCurvePk);
    }
    return sharedK;
}
exports.getOrCreateSharedKey = getOrCreateSharedKey;
function tag(obj, recipientPk) {
    const sharedKey = getOrCreateSharedKey(recipientPk);
    const objCopy = lib_types_1.Utils.safeJsonParse(core.stringify(obj));
    objCopy.publicKey = State.getNodeInfo().publicKey;
    core.tagObj(objCopy, sharedKey);
    return objCopy;
}
exports.tag = tag;
function authenticate(msg) {
    const sharedKey = getOrCreateSharedKey(msg.publicKey);
    return core.authenticateObj(msg, sharedKey);
}
exports.authenticate = authenticate;
//# sourceMappingURL=Crypto.js.map