import { CheckpointStatusType } from '../dbstore/checkpointStatus';
export declare enum CheckpointType {
    Cycle = 0,
    OriginalTx = 1,
    Receipt = 2
}
export declare const checkpointStatusToTypeMap: {
    0: CheckpointStatusType;
    2: CheckpointStatusType;
    1: CheckpointStatusType;
};
export declare class CheckpointData<T> {
    a: string;
    t: number;
    h: string;
    c: number;
    d: T;
    constructor(a: string, t: number, h: string, c: number, d: T);
}
export declare class CheckpointRadixDigest {
    radix: string;
    hash: string;
    itemCount: number;
    constructor(radix: string, hash: string, itemCount: number);
}
export declare class CheckpointRadixEntry<T> {
    digest: CheckpointRadixDigest;
    sortedData: CheckpointData<T>[];
    constructor(radix: string);
    updateDigest(): void;
    private computeHash;
}
export interface DataPersistenceCallbacks<T> {
    updateData: (data: CheckpointData<T>) => Promise<void>;
    validateData: (data: CheckpointData<T>) => Promise<boolean>;
}
export declare class CheckpointBucketManager<T> {
    private persistenceCallbacks;
    checkpointBuckets: Map<string, CheckpointBucket<T>>;
    validateData: (data: CheckpointData<T>) => Promise<boolean>;
    updateData: (data: CheckpointData<T>) => Promise<void>;
    checkpointType: CheckpointType;
    lastFailedBucketTime: number;
    bucketsToPersist: Map<string, CheckpointBucket<T>>;
    constructor(persistenceCallbacks: DataPersistenceCallbacks<T>, checkpointType: CheckpointType);
    hasLastFailedBucketExceededDuration(): boolean;
    addData(data: CheckpointData<T>, bucketID: string): void;
    persistBucketsData(): Promise<void>;
    update(): Promise<void>;
    onHashDigestsReceived(senderAddress: string, bucketID: string, radixDigests: CheckpointRadixDigest[]): void;
    onExchangeRadixEntries(bucketID: string, entries: CheckpointRadixEntry<T>[]): CheckpointRadixEntry<T>[];
}
export declare class CheckpointBucket<T> {
    startTime: number;
    endTime: number;
    bucketID: string;
    hasUpdatesToShare: boolean;
    sentDigestsCount: number;
    receivedDigestCount: number;
    lastProcessedDigestCount: number;
    radixEntries: Map<string, CheckpointRadixEntry<T>>;
    peerRadixDigests: Map<string, RadixDigestTally>;
    validateData: (data: CheckpointData<T>) => Promise<boolean>;
    updateData: (data: CheckpointData<T>) => Promise<void>;
    GiveUpAge: number;
    BucketMatureAge: number;
    checkpointType: CheckpointType;
    constructor(startTime: number, endTime: number, bucketID: string, validateData: (data: CheckpointData<T>) => Promise<boolean>, updateData: (data: CheckpointData<T>) => Promise<void>, checkpointType: CheckpointType);
    addData(data: CheckpointData<T>): Promise<void>;
    shareRadixDigests(radixList?: string[]): Promise<void>;
    update(currentTime: number): void;
    writeToFileAndAlert(): void;
    evaluateDigestConsensus(): void;
    private requestRepairForRadix;
    exchangeAndRepairRadix(peerAddress: string, radix: string): Promise<void>;
    onHashDigestsReceived(senderAddress: string, bucketID: string, radixDigests: CheckpointRadixDigest[]): void;
    onExchangeRadixEntries(bucketID: string, entries: CheckpointRadixEntry<T>[]): void;
    private validateExchangeInput;
    private initializeNewTally;
    private updateTallyForPeer;
    private processBatchEntries;
    private mergeEntryData;
    private updateTallyAfterMerge;
    toJSON(): {
        startTime: number;
        endTime: number;
        bucketID: string;
        checkpointType: CheckpointType;
        hasUpdatesToShare: boolean;
        sentDigestsCount: number;
        receivedDigestCount: number;
        lastProcessedDigestCount: number;
        BucketMatureAge: number;
        GiveUpAge: number;
        radixEntries: {
            [k: string]: CheckpointRadixEntry<T>;
        };
        peerRadixDigests: {
            [k: string]: RadixDigestTally;
        };
    };
}
export declare class RadixDigestTally {
    radix: string;
    hashTally: Map<string, number>;
    peerDigests: Map<string, CheckpointRadixDigest>;
    constructor(radix: string);
}
