"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCheckpointManager = void 0;
const Logger = require("../Logger");
const CheckpointData_1 = require("./CheckpointData");
const CycleData_1 = require("./CycleData");
const OriginalTxsData_1 = require("./OriginalTxsData");
const ReceiptData_1 = require("./ReceiptData");
// Map of checkpoint types to their respective managers.
const checkpointManagers = {
    [CheckpointData_1.CheckpointType.Cycle]: CycleData_1.cycleCheckpointManager,
    [CheckpointData_1.CheckpointType.OriginalTx]: OriginalTxsData_1.originalTxCheckpointManager,
    [CheckpointData_1.CheckpointType.Receipt]: ReceiptData_1.receiptCheckpointManager,
};
/**
 * Retrieves the checkpoint manager for the specified checkpoint type.
 * @param checkpointType - The type of checkpoint for which to retrieve the manager.
 * @returns The corresponding CheckpointBucketManager or undefined if not found.
 */
const getCheckpointManager = (checkpointType) => {
    try {
        return checkpointManagers[checkpointType];
    }
    catch (error) {
        Logger.mainLogger.error('Error getting checkpoint manager:', error);
        return undefined;
    }
};
exports.getCheckpointManager = getCheckpointManager;
//# sourceMappingURL=Utils.js.map