"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkReceiptsDataBetweenArchivers = exports.checkCyclesDataBetweenArchivers = exports.checkDataSyncBetweenArchivers = void 0;
const P2P_1 = require("../../P2P");
const lib_types_1 = require("@shardeum-foundation/lib-types");
async function checkDataSyncBetweenArchivers(ip, numberOfArchivers) {
    const dataInfos = {
        archiverInfo: [],
        totalCycles: [],
        totalAccounts: [],
        totalTransactions: [],
        totalReceipts: [],
    };
    for (let i = 0; i < numberOfArchivers; i++) {
        const archiverURL = ip + ':' + (4000 + i);
        const res = (await (0, P2P_1.getJson)(`http://${archiverURL}/totalData`));
        if (typeof res === 'object' && res !== null && 'cycleInfo' in res) {
            dataInfos.archiverInfo.push(archiverURL);
            dataInfos.totalCycles.push(res.totalCycles);
            dataInfos.totalAccounts.push(res.totalAccounts);
            dataInfos.totalTransactions.push(res.totalTransactions);
            dataInfos.totalReceipts.push(res.totalReceipts);
        }
        else
            console.log(`Fail to fetch totalData from archiver ${archiverURL}`);
    }
    if (dataInfos.archiverInfo.length > 1) {
        const expectedTotalCycles = dataInfos.totalCycles[0];
        const totalCyclesIsMatched = dataInfos.totalCycles.every((cycle) => cycle === expectedTotalCycles);
        if (totalCyclesIsMatched)
            console.log('TotalCycles is matched!');
        const expectedTotalAccounts = dataInfos.totalAccounts[0];
        const totalAccountsIsMatched = dataInfos.totalAccounts.every((cycle) => cycle === expectedTotalAccounts);
        if (totalAccountsIsMatched)
            console.log('TotalAccounts is matched!');
        const expectedTotalTransactions = dataInfos.totalTransactions[0];
        const totalTransactionsIsMatched = dataInfos.totalTransactions.every((cycle) => cycle === expectedTotalTransactions);
        if (totalTransactionsIsMatched)
            console.log('TotalTransactions is matched!');
        const expectedTotalReceipts = dataInfos.totalReceipts[0];
        const totalReceiptsIsMatched = dataInfos.totalReceipts.every((cycle) => cycle === expectedTotalReceipts);
        if (totalReceiptsIsMatched)
            console.log('TotalReceipts is matched!');
    }
}
exports.checkDataSyncBetweenArchivers = checkDataSyncBetweenArchivers;
async function checkCyclesDataBetweenArchivers(ip, numberOfArchivers) {
    const dataInfos = {};
    for (let i = 0; i < numberOfArchivers; i++) {
        const archiverURL = ip + ':' + (4000 + i);
        const res = (await (0, P2P_1.getJson)(`http://${archiverURL}/cycleinfo/100`));
        if (res) {
            // eslint-disable-next-line security/detect-object-injection
            dataInfos[archiverURL] = res.cycleInfo;
        }
        else
            console.log(`Fail to fetch cycle data from archiver ${archiverURL}`);
    }
    if (Object.keys(dataInfos).length > 0) {
        const archiverInfos = Object.keys(dataInfos);
        const expectedCycles = dataInfos[archiverInfos[0]];
        let allCyclesAreMatched = true;
        for (let i = 0; i < expectedCycles.length; i++) {
            // eslint-disable-next-line security/detect-object-injection
            const cycleInfo = expectedCycles[i];
            const cycleInfoToMatch = lib_types_1.Utils.safeStringify(cycleInfo);
            for (let j = 1; j < archiverInfos.length; j++) {
                // console.log(cycleInfo.counter, dataInfos[archiverInfos[j]][i].counter)
                // eslint-disable-next-line security/detect-object-injection
                if (cycleInfoToMatch !== lib_types_1.Utils.safeStringify(dataInfos[archiverInfos[j]][i])) {
                    allCyclesAreMatched = false;
                    console.log(`Cycle ${cycleInfo.counter} is not matched between archivers!`);
                }
            }
        }
        if (allCyclesAreMatched)
            console.log('All the latest 100 cycles are match!');
    }
}
exports.checkCyclesDataBetweenArchivers = checkCyclesDataBetweenArchivers;
async function checkReceiptsDataBetweenArchivers(ip, numberOfArchivers) {
    const randomPort = getRndInteger(0, numberOfArchivers - 1);
    const randomArchiver = ip + ':' + (4000 + randomPort);
    const response = (await (0, P2P_1.getJson)(`http://${randomArchiver}/receipt/1`));
    const latestReceiptInfo = response.receipts[0];
    const endCycle = latestReceiptInfo.cycle;
    const startCycle = latestReceiptInfo.cycle - 10;
    const dataInfos = {
        archiverInfo: [],
        cycles: {},
    };
    for (let i = startCycle; i <= endCycle; i++) {
        // eslint-disable-next-line security/detect-object-injection
        dataInfos.cycles[i] = [];
    }
    for (let i = 0; i < numberOfArchivers; i++) {
        const archiverURL = ip + ':' + (4000 + i);
        const res = (await (0, P2P_1.getJson)(`http://${archiverURL}/receipt?startCycle=${startCycle}&endCycle=${endCycle}&type=tally`));
        if (res && res.receipts) {
            dataInfos.archiverInfo.push(archiverURL);
            for (const receiptInfo of res.receipts) {
                dataInfos.cycles[receiptInfo.cycle].push(receiptInfo.receipts);
            }
            // Place 0 for cycles that are not in the query
            for (let j = startCycle; j <= endCycle; j++) {
                let found = false;
                for (const receiptInfo of res.receipts) {
                    if (j === receiptInfo.cycle)
                        found = true;
                }
                // eslint-disable-next-line security/detect-object-injection
                if (!found)
                    dataInfos.cycles[j].push(0);
            }
        }
        else
            console.log(`Fail to fetch receipt data between cycles from archiver ${archiverURL}`);
    }
    if (dataInfos.archiverInfo.length > 1) {
        let allReceiptsAreMatched = true;
        for (let i = startCycle; i <= endCycle; i++) {
            // eslint-disable-next-line security/detect-object-injection
            const expectedReceipts = dataInfos.cycles[i][0];
            // eslint-disable-next-line security/detect-object-injection
            const receiptsIsMatched = dataInfos.cycles[i].every((receipts) => receipts === expectedReceipts);
            if (!receiptsIsMatched) {
                allReceiptsAreMatched = false;
                console.log(`Receipts Count do not match in cycle ${i}`);
            }
        }
        if (allReceiptsAreMatched)
            console.log(`All receipts count of cycles between ${startCycle} - ${endCycle} are matched!`);
    }
}
exports.checkReceiptsDataBetweenArchivers = checkReceiptsDataBetweenArchivers;
function getRndInteger(min, max) {
    return Math.floor(Math.random() * (max - min + 1)) + min;
}
//# sourceMappingURL=mulitpleArchivers.js.map